@@ -6,7 +6,7 @@ from pathlib import Path
 from typing import Dict, Iterable, List, Optional, Sequence
 
 import click
-from pkg_resources import safe_name
+from pip._vendor.pkg_resources import safe_name
 
 from pdm.cli.utils import (
     check_project_file,
@@ -14,6 +14,7 @@ from pdm.cli.utils import (
     format_lockfile,
     format_toml,
     save_version_specifiers,
+    set_env_in_reg,
 )
 from pdm.exceptions import NoPythonVersion, PdmUsageError, ProjectError
 from pdm.formats import FORMATS
@@ -149,7 +150,6 @@ def do_add(
     save_version_specifiers(requirements, resolved, save)
     project.add_dependencies(requirements)
     lockfile = project.lockfile
-    lockfile["root"]["content_hash"] = "md5:" + project.get_content_hash("md5")
     project.write_lockfile(lockfile, False)
 
     if sync:
@@ -236,7 +236,6 @@ def do_update(
         save_version_specifiers(updated_deps, resolved, save)
         project.add_dependencies(updated_deps)
         lockfile = project.lockfile
-        lockfile["root"]["content_hash"] = "md5:" + project.get_content_hash("md5")
         project.write_lockfile(lockfile, False)
 
 
@@ -540,18 +539,17 @@ def print_pep582_command(shell: str = "AUTO"):
     """Print the export PYTHONPATH line to be evaluated by the shell."""
     import shellingham
 
+    if os.name == "nt":
+        set_env_in_reg("PYTHONPATH", PEP582_PATH)
+        return
+    lib_path = PEP582_PATH.replace("'", "\\'")
     if shell == "AUTO":
         shell = shellingham.detect_shell()[0]
     shell = shell.lower()
-    lib_path = PEP582_PATH.replace("'", "\\'")
     if shell in ("zsh", "bash"):
         result = f"export PYTHONPATH='{lib_path}':$PYTHONPATH"
     elif shell == "fish":
         result = f"set -x PYTHONPATH '{lib_path}' $PYTHONPATH"
-    elif shell == "powershell":
-        result = f'$env:PYTHONPATH="{lib_path};$env:PYTHONPATH"'
-    elif shell == "cmd":
-        result = f"set PYTHONPATH={lib_path};%PYTHONPATH%"
     elif shell in ("tcsh", "csh"):
         result = f"setenv PYTHONPATH '{lib_path}':$PYTHONPATH"
     else:
