@@ -8,11 +8,11 @@ from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Type, Uni
 
 import tomlkit
 from pip._vendor.pkg_resources import safe_name
-from pip_shims import shims
 
 from pdm._types import Source
 from pdm.exceptions import ProjectError
 from pdm.iostream import stream
+from pdm.models import pip_shims
 from pdm.models.caches import CandidateInfoCache, HashCache
 from pdm.models.candidates import Candidate
 from pdm.models.environment import Environment, GlobalEnvironment
@@ -43,7 +43,7 @@ class Project:
     PYPROJECT_FILENAME = "pyproject.toml"
     PDM_NAMESPACE = "tool.pdm"
     DEPENDENCIES_RE = re.compile(r"(?:(.+?)-)?dependencies")
-    PYPROJECT_VERSION = "0.0.1"
+    PYPROJECT_VERSION = "2"
     GLOBAL_PROJECT = Path.home() / ".pdm" / "global-project"
 
     @classmethod
@@ -281,15 +281,13 @@ class Project:
         return SpinnerReporter(spinner, requirements)
 
     def get_project_metadata(self) -> Dict[str, Any]:
-        content_hash = self.get_content_hash("md5")
-        data = {
-            "meta_version": self.PYPROJECT_VERSION,
-            "content_hash": f"md5:{content_hash}",
-        }
+        content_hash = tomlkit.string("sha256:" + self.get_content_hash("sha256"))
+        content_hash.trivia.trail = "\n\n"
+        data = {"lock_version": self.PYPROJECT_VERSION, "content_hash": content_hash}
         return data
 
     def write_lockfile(self, toml_data: Container, show_message: bool = True) -> None:
-        toml_data.update({"root": self.get_project_metadata()})
+        toml_data["metadata"].update(self.get_project_metadata())
 
         with atomic_open_for_write(self.lockfile_file) as fp:
             fp.write(tomlkit.dumps(toml_data))
@@ -298,7 +296,7 @@ class Project:
         self._lockfile = None
 
     def make_self_candidate(self, editable: bool = True) -> Candidate:
-        req = parse_requirement(shims.path_to_url(self.root.as_posix()), editable)
+        req = parse_requirement(pip_shims.path_to_url(self.root.as_posix()), editable)
         req.name = self.meta.name
         return Candidate(
             req, self.environment, name=self.meta.name, version=self.meta.version
@@ -323,7 +321,9 @@ class Project:
             can.marker = req.marker
             can.hashes = {
                 item["file"]: item["hash"]
-                for item in self.lockfile["metadata"].get(f"{req.key} {version}", [])
+                for item in self.lockfile["metadata"]
+                .get("files", {})
+                .get(f"{req.key} {version}", [])
             } or None
             result[req.identify()] = can
         if section in ("default", "__all__") and self.meta.name and self.meta.version:
@@ -347,7 +347,11 @@ class Project:
     def is_lockfile_hash_match(self) -> bool:
         if not self.lockfile_file.exists():
             return False
-        hash_in_lockfile = str(self.lockfile["root"]["content_hash"])
+        hash_in_lockfile = str(
+            self.lockfile.get("metadata", {}).get("content_hash", "")
+        )
+        if not hash_in_lockfile:
+            return False
         algo, hash_value = hash_in_lockfile.split(":")
         content_hash = self.get_content_hash(algo)
         return content_hash == hash_value
@@ -387,7 +391,7 @@ class Project:
         ) as f:
             f.write(tomlkit.dumps(self.pyproject))
         if show_message:
-            stream.echo("Changes are written to pyproject.toml.")
+            stream.echo(f"Changes are written to {stream.green('pyproject.toml')}.")
         self._pyproject = None
 
     @property
@@ -420,9 +424,9 @@ wheel = "*"
         path.mkdir(parents=True, exist_ok=True)
         return path
 
-    def make_wheel_cache(self) -> shims.WheelCache:
-        return shims.WheelCache(
-            self.cache_dir.as_posix(), shims.FormatControl(set(), set())
+    def make_wheel_cache(self) -> pip_shims.WheelCache:
+        return pip_shims.WheelCache(
+            self.cache_dir.as_posix(), pip_shims.FormatControl(set(), set())
         )
 
     def make_candidate_info_cache(self) -> CandidateInfoCache:
