@@ -239,13 +239,6 @@ def test_import_other_format_file(project, invoke, filename):
     assert result.exit_code == 0
 
 
-@pytest.mark.pypi
-def test_search_package(project, invoke):
-    result = invoke(["search", "requests"], obj=project)
-    assert result.exit_code == 0
-    assert len(result.output.splitlines()) > 0
-
-
 @pytest.mark.pypi
 def test_show_package_on_pypi(invoke):
     result = invoke(["show", "ipython"])
@@ -261,6 +254,7 @@ def test_export_to_requirements_txt(invoke, fixture_project):
     project = fixture_project("demo-package")
     requirements_txt = project.root / "requirements.txt"
     requirements_no_hashes = project.root / "requirements_simple.txt"
+    requirements_pyproject = project.root / "requirements.ini"
 
     result = invoke(["export"], obj=project)
     assert result.exit_code == 0
@@ -270,6 +264,10 @@ def test_export_to_requirements_txt(invoke, fixture_project):
     assert result.exit_code == 0
     assert result.output.strip() == requirements_no_hashes.read_text().strip()
 
+    result = invoke(["export", "--pyproject"], obj=project)
+    assert result.exit_code == 0
+    assert result.output.strip() == requirements_pyproject.read_text().strip()
+
     result = invoke(
         ["export", "-o", str(project.root / "requirements_output.txt")], obj=project
     )
